#
# spec file for package exempi
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sonum 8
Name:           exempi
Version:        2.6.5
Release:        1.2
Summary:        XMP support library
License:        BSD-3-Clause
Group:          Development/Libraries/C and C++
URL:            https://libopenraw.freedesktop.org/exempi/
Source0:        https://libopenraw.freedesktop.org/download/%{name}-%{version}.tar.xz
Source1:        https://libopenraw.freedesktop.org/download/%{name}-%{version}.tar.xz.asc
Source2:        %{name}.keyring
Source3:        baselibs.conf
BuildRequires:  gcc-c++
BuildRequires:  libboost_test-devel
BuildRequires:  libexpat-devel
BuildRequires:  pkgconfig
BuildRequires:  zlib-devel

%description
Exempi is a library for XMP parsing and I/O. XMP is a kind of
metadata for images and PDF.

%package -n libexempi%{sonum}
Summary:        XMP support library
Group:          System/Libraries

%description -n libexempi%{sonum}
Exempi is a library for XMP parsing and I/O. XMP (Extensible Metadata
Platform) facilitates embedding metadata in files using a subset of
RDF. Most notably, XMP supports embedding metadata in PDF and many
image formats.

%package tools
Summary:        Tools from Exempi, an XMP support library
Group:          Productivity/Graphics/Other

%description tools
Exempi is a library for XMP parsing and I/O. XMP is a kind of
metadata for images and PDF.

This subpackage contains utilities from the Exempi project.

%package -n libexempi-devel
Summary:        Development files for the Exempi XMP support library
Group:          Development/Libraries/C and C++
Requires:       glibc-devel
Requires:       libexempi%{sonum} = %{version}

%description -n libexempi-devel
Exempi is a library for XMP metadata parsing and doing I/O with it.

This subpackage contains the header files for building applications
with Exempi.

%prep
%setup -q

%build
export CXXFLAGS="%{optflags} -fno-strict-aliasing"
%configure
%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print
find %{buildroot} -type f -name "*.a" -delete -print

%check
%if ! 0%{?qemu_user_space_build}
%make_build check
%endif

%post -n libexempi%{sonum} -p /sbin/ldconfig
%postun -n libexempi%{sonum} -p /sbin/ldconfig

%files -n libexempi%{sonum}
%license COPYING
%doc README.md NEWS
%{_libdir}/lib*.so.*

%files tools
%license COPYING
%{_bindir}/exempi
%{_mandir}/man1/exempi.1%{?ext_man}

%files -n libexempi-devel
%license COPYING
%{_libdir}/lib*.so
%{_includedir}/exempi-2.0
%{_libdir}/pkgconfig/*.pc

%changelog
* Sun Mar 17 2024 Dirk Müller <dmueller@suse.com>
- update to 2.6.5:
  * Update XMPCore to Adobe XMP SDK v2023.12
  - Bug fixes
  - C++17 compliance changes
  - Changes to remove deprecated APIs
  - Removing unimplemented APIs in XMPUtils header
  * Fix a potential nullptr dereference.
  * Update XMPCore to Adobe XMP SDK v2023.07
  - Security Fixes.
  - Fix Exif Date missing seconds values.
    https://github.com/adobe/XMP-Toolkit-SDK/issues/50
  * Fix some portability build issues with dlopen on BSD:
  * Added missing file type constants from the XMP_SDK.
* Tue Feb 21 2023 Paolo Stivanin <info@paolostivanin.com>
- update to 2.6.3:
  * Fix null to int assignement error.
* Sun Dec  4 2022 Dirk Müller <dmueller@suse.com>
- update to 2.6.2:
  - Update XMPCore to Adobe XMP SDK v2022.06
  - Build system fixes that don't matter.
  - Fix a typo in an ID3 genre string
  - Build XMP_SDK with some fatal warnings:
  - -Werror=missing-field-initializers
  - -Werror=misleading-indentation
  - -Werror=class-memaccess
  - Remove (deprecated) boost_test_minimal
  - Remove old .sym file (Daniel Kolesa)
  - Added --enable-samples (default = yes) (Fabrice Fontaine)
* Mon May  9 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 2.6.1:
  * Update XMPCore to Adobe XMP SDK v2021.10
  * Some fixes previously done in Exempi are now upstream
- Install the NEWS file instead of the obsolete ChangeLog one
* Fri Mar 19 2021 Michael Gorse <mgorse@suse.com>
- Update baselibs.conf to reflect new sonum.
* Thu Jan 14 2021 andy great <andythe_great@pm.me>
- Remove --disable-static because it cause build to fail.
- Update to version 2.5.2.
  * Bug #18: Remove an unnecessary message to stdout in the exempi tool.
    https://gitlab.freedesktop.org/libopenraw/exempi/-/issues/18
  * Bug #20: Test file formats. This also change the GIF sample to GIF89a.
    https://gitlab.freedesktop.org/libopenraw/exempi/-/issues/20
  * Bug #17: `make check` should build more reliably now.
    https://gitlab.freedesktop.org/libopenraw/exempi/issues/17
  * MR !1: Remove deprecated C++ to compile with C++17.
    https://gitlab.freedesktop.org/libopenraw/exempi/merge_requests/1
  * MR !2: Fix a build failure with C++17.
    https://gitlab.freedesktop.org/libopenraw/exempi/merge_requests/2
- Updates for version 2.5.1.
  * Bug #9: [CVE-2018-12648] Fix null-pointer-dereference in WEBP.
    https://gitlab.freedesktop.org/libopenraw/exempi/issues/9
  * Bug #12: Invalid WEBP cause a memory overflow.
    https://gitlab.freedesktop.org/libopenraw/exempi/issues/12
  * Bug #13: Fix a buffer a overflow in ID3 support on invalid MP3.
    https://gitlab.freedesktop.org/libopenraw/exempi/issues/13
  * Bug #14: Invalid MP3 cause a memory overflow.
    https://gitlab.freedesktop.org/libopenraw/exempi/issues/14
- Updates for version 2.5.0.
  * Upgrade XMPCore to Adobe XMP SDK CC 2016.07
  * Support for iOS in XMPFiles
  * New DOM based API’s are added in XMP Core to access metadata tree
    hierarchy. (not exposed yet in Exempi)
  * Added support XMP/metadata in utf-8 encoded uncompressed SVG
    files in XMPFiles.
  * Added support of GIF handler in XMPFiles.
  * Added support for reconciliation of iXML’s TRACK_LIST and its
    components to get microphone data.
  * Added support for IFDs of type 13 in TIFF.
  * Added support for MPEG4 videos shot from Google Nexus 5 camera.
  * Restructured the implementation of XDCAM Handler to support
    File Access Mode (FAM) and Simple Access Mode (SAM)
  * Added built-in support for iXML namespace in XMPCore.
  * Modified the alias tiff:ImageDescription for dc:description as
    language alternative array instead of simple property.
  * Lot of bug fixes in XMPFiles and XMPCore.
  * Removed Exempi provided support for GIF in favour of Adobe's.
    Only GIF89a is supported.
  * New: API NS_XML constant
  * Bug #5: Restrict the exported symbols. Only the symbols marked
    with API_EXPORT are exported by the shared library as to not
    allow another library to import the XMP SDK symbols.
    https://gitlab.freedesktop.org/libopenraw/exempi/issues/5
  * Bug #105580: Access memory aligned on ARM.
    https://bugs.freedesktop.org/show_bug.cgi?id=105580
  * Added tests for Adobe SDK.
  * Fixed warnings and other issues and Adobe SDK.
  * Compile with much more warnings enabled.
* Wed Mar 14 2018 jengelh@inai.de
- Extend descriptions.
* Wed Mar 14 2018 kbabioch@suse.com
- Update to 2.4.5:
  * Fix a buffer overflow in the PSD parser. (CVE-2018-7730 bnc#1085295)
  * Fix a buffer overflow in the TIFF parser. (CVE-2018-7728 bnc#1085297)
  * Fix a buffer overflow in PostScript parser. (CVE-2018-7729 bnc#1085296)
  * Fix a null dereference in WEBP parser. (CVE-2018-7731 bnc#1085294)
  * Properly initialize pointers in WEBP.
  * Fix an infinite loop in RIFF parser.
  * Fix an infinite loop in QuickTime parser.
  * Fix an infinite loop in ASF parser.
  * Adjust minimum version for gcc in documentation.
  * Fix a buffer overrun, memcpy() on overlapping regions, use after free in
    the exception handling.  Fix a fatal assert with corrupt WEBP.
  * Fix a crash on a corrupt file.
  * Upgrade XMPCore to Adobe XMP CC 2014.12.
  * New flag to optimize layout on MPEG4 files.
  * GoPro MPEG4 video files support.
  * Improved JPEG support.
  * iXML support in WAVE files.
  * Several bugs and memory leaks fixes.
  * Changes from Adobe XMP CC 2013.06.
  * Pluggable file handlers (not exposed yet in Exempi)
  * Support for Exif 2.3 properties
  * New RIFF file handler
  * Better Postscript support.
  * Lot of bug fixes.
  * Now require (partial) C++11 support to compile (gcc 4.4.7 tested)
  * WebP format handler (contributed: Frankie Dintino, The Atlantic)
  * Several API improvements
  * Fix potential crash with corrupt TIFF file.
  * Fix header to pass -Wstrict-prototypes
* Wed Feb  1 2017 adam.majer@suse.de
- use individual libboost-*-devel packages instead of boost-devel
* Sun Nov 22 2015 mpluskal@suse.com
- Add gpg signature
- Cleanup spec file with spec-cleaner
* Fri Dec 26 2014 zaitor@opensuse.org
- Update to version 2.2.2:
  + Public header cleanup and documentation update.
  + Update Doxygen config.
  + fdo#73058: Add missing include for MacOS.
  + fdo#72810: Fix typo in date test in MP3 handler.
  + fdo#83313: Fix crash on invalid Exif (from Samsung).
  + Fix valgrind testing for xmpcore.sh.
  + Fix delete / delete[] mismatch in ID3_Support.hpp.
- Add baselibs.conf to Source to comply with current rules in
  Factory.
* Sun Jun 30 2013 zaitor@opensuse.org
- Update to version 2.2.1:
  + fdo#54011: Use POSIX API for files on MacOS.
  + fdo#58175: Replace OS X FlatCarbon headers.
  + Added a manpage for exempi(1).
  + Added the -n option to the command line for arbitrary
    namespaces.
* Sun Feb 26 2012 dmueller@suse.de
- fix build under qemu
* Thu Feb 23 2012 vuntz@opensuse.org
- Update to version 2.2.0:
  + New 'exempi' command line tool.
  + Upgrade XMPCore to Adobe XMP 5.1.2
  - Quicktime support now works without Quicktime.
  - Reconciliation with ID3v2.
  - "Blessed" 64-bits support (we already had it in exempi).
  - Slight change in the way XMP are written for MWG compliance.
  - Fixed a serious bug with RIFF.
  - Change in the way local text encoding is dealt with.
  - Alternative languages behave slightly differently by changing
    how the default language property is managed.
  - Probably a bunch of bugs fixed that I don't know about.
  + Update unit tests.
  - Refactor the fixtures.
  + Use automake silent rules instead of shave. (build only)
  + "make dist" generate a bzip2 archive as well. (build only)
  + Remove some obsolete warning flags. (build only)
  + Build xmpcommandtool
  + Several new APIs.
  + Bug fixes: fdo#37747.
- Drop exempi-no-shave.patch: shave is not used upstream anymore.
- Drop libtool BuildRequires, autoreconf call and
  - -disable-silent-rules that were used because of patch above.
- Create a tools subpackage for new exempi command line tool.
- Change group of libexempi3 from "Development/Libraries/C and C++"
  to System/Libraries.
- Use V=1 during the build to get a verbose build.
* Fri Sep 30 2011 coolo@suse.com
- use original tar
* Fri Sep 30 2011 coolo@suse.com
- add libtool as buildrequire to make the spec file more reliable
* Sun Apr 24 2011 toddrme2178@gmail.com
- Add 32bit compatibility libraries
* Thu Dec  9 2010 cristian.rodriguez@opensuse.org
- run make check
- Disable usage of "shave-libtool" that messes up post build checks
  provide --disable-silent-rules
* Tue Sep  7 2010 vuntz@opensuse.org
- Add pkg-config BuildRequires to get a pkgconfig() provides for
  the devel subpackage.
* Mon Jul 20 2009 vuntz@novell.com
- Update to version 2.1.1:
  + Added shave to the build system for sane output. (build only)
  + fdo#16030: if the property is an array or struct allow "" to be
    passed as a value.
  + fdo#19312: source/XMPFiles/FileHandlers/P2_Handler.cpp was
    using an improper string comparison. (made rpmlint unhappy).
  + fdo#20554: Missing file on MacOS X.
  + fdo#20554: Detect ldflags properly.
  + fdo#20622: Catch unhandled exceptions in
    xmp_files_can_put_xmp().
  + fdo#21934: Mismatched new [] / delete.
  + fdo#22554: Fix a SIGFPE encountered on some invalid files.
    (bgo#586720)
- Drop exempi-rpmlint.diff: fixed upstream.
- Drop exempi-gcc44.patch: fixed upstream.
* Tue Apr 28 2009 vuntz@novell.com
- Add exempi-gcc44.patch to fix build with gcc 4.4.
- Remove AutoReqProv: it's default now.
* Fri Jan  9 2009 crrodriguez@suse.de
- remove static libraries and "la" files
- correct -devel package deps
* Wed Dec 24 2008 hfiguiere@suse.de
- New upstream version 2.1.0
  + Upgrade XMPCore to Adobe XMP 4.4.2
  + New: NS_PDF namespace for PDF.
  + New: API xmp_prefix_namespace_uri() and xmp_namespace_prefix(). fdo#14962.
  + Bug: make sure boost >1.35 does not fail test with system().
  + Bug: unit test now use boost/test/minimal.hpp to work with more boost
    install. (known boost.test bug)
  + Bug: fix a typo in a CHECK_PTR call causing warnings on gcc < 4.
  + Bug: no longer define UNIX_ENV in exempi.cpp and let CPPFLAGS do it.
  + Bug fdo#16139: the list of exported symbols was too large.
  + Bug fdo#18635: fix crasher.
- Added patch exempi-rpmlint.diff to make rpmlint happy. fdo#19312
- Added zlib-devel as a dependency
- Remove .la and disable static
* Wed Oct 22 2008 maw@suse.de
- Make debug packages require a specific %%{version}-%%{release}.
* Wed Aug 13 2008 hfiguiere@suse.de
- New upstream version 2.0.2
  + Fix bug fdo#16598: TLS detection.
  + Better error management
  + Bugs fdo#14612 and fdo#14613
* Wed Aug  6 2008 mauro@suse.de
-Update to 2.0.1
  + bgo#14612: no stdbool.h for Sun compilers.
  + bgo#14613: check for iconv() const-ness.
  + Make the error checking more robust.
  + Make error code thread-safe (ie local to the thread).
* Fri Aug  1 2008 ro@suse.de
- fix requires for debuginfo package
* Wed Apr  2 2008 vuntz@suse.de
- New upstream version 2.0.0:
  + Bug fdo#14614, Bug fdo#15263: endian detection in configure.
  + Bug fdo#14615: missing includes for Solaris.
* Fri Mar 14 2008 hfiguiere@suse.de
- New upstream version 1.99.9
  + Typo fix in API
  + Buffer overflow fix in GIF handler (bgo #484105)
* Fri Jan 18 2008 jpr@suse.de
- Initial checkin
